@@ -5,14 +5,6 @@ use base qw(Business::ISBN);
 use Business::ISBN qw(:all);
 use Data::Dumper;
 
-use subs qw(
-	_checksum
-	INVALID_COUNTRY_CODE
-	INVALID_PUBLISHER_CODE
-	BAD_CHECKSUM
-	GOOD_ISBN
-	BAD_ISBN
-	);
 use vars qw(
 	$VERSION
 	$debug
@@ -22,7 +14,7 @@ use Carp qw(carp croak cluck);
 
 my $debug = 0;
 
-$VERSION   = '2.09';
+$VERSION   = '3.003';
 
 sub _max_length { 13 }
 
@@ -100,6 +92,8 @@ sub _checksum {
 
 __END__
 
+=encoding utf8
+
 =head1 NAME
 
 Business::ISBN13 - work with 13 digit International Standard Book Numbers
@@ -116,7 +110,7 @@ See L<Business::ISBN>
 
 This source is in Github.
 
-	https://github.com/briandfoy/business--isbn
+	https://github.com/briandfoy/business-isbn
 
 =head1 AUTHOR
 
@@ -124,8 +118,9 @@ brian d foy C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2001-2014, brian d foy, All Rights Reserved.
+Copyright © 2001-2016, brian d foy <bdfoy@cpan.org>. All rights reserved.
 
-You may redistribute this under the same terms as Perl itself.
+This module is licensed under the Artistic License 2.0. See the LICENSE
+file in the distribution, or https://opensource.org/licenses/Artistic-2.0
 
 =cut
